@@ -59,11 +59,21 @@ void my_connack_callback(int result)
 
 void my_net_write_callback(int command)
 {
-	if(command == PUBLISH){
+	if(qos == 0 && command == PUBLISH){
 		mqtt3_raw_disconnect(gcontext);
 	}
 }
 
+void my_puback_callback(int mid)
+{
+	mqtt3_raw_disconnect(gcontext);
+}
+
+void my_pubcomp_callback(int mid)
+{
+	mqtt3_raw_disconnect(gcontext);
+}
+
 void print_usage(void)
 {
 	printf("mosquitto_pub is a simple mqtt client that will publish a message on a single topic and exit.\n\n");
@@ -175,6 +185,8 @@ int main(int argc, char *argv[])
 	}
 	client_connack_callback = my_connack_callback;
 	client_net_write_callback = my_net_write_callback;
+	client_puback_callback = my_puback_callback;
+	client_pubcomp_callback = my_pubcomp_callback;
 
 	if(client_connect(&context, host, port, id, keepalive)){
 		fprintf(stderr, "Unable to connect.\n");
