@@ -40,6 +40,13 @@ POSSIBILITY OF SUCH DAMAGE.
 #include <config.h>
 #include <mqtt3.h>
 
+#ifdef WITH_CLIENT
+/* Client callback for puback events - this WILL change. */
+void (*client_puback_callback)(int) = NULL;
+/* Client callback for pubcomp events - this WILL change. */
+void (*client_pubcomp_callback)(int) = NULL;
+#endif
+
 int mqtt3_packet_handle(mqtt3_context *context)
 {
 	if(!context) return 1;
@@ -90,6 +97,12 @@ int mqtt3_handle_puback(mqtt3_context *context)
 	if(mqtt3_read_uint16(context, &mid)) return 1;
 	mqtt3_log_printf(MQTT3_LOG_DEBUG, "Received PUBACK from %s (Mid: %d)", context->id, mid);
 
+#ifdef WITH_CLIENT
+	if(client_puback_callback){
+		client_puback_callback(mid);
+	}
+#endif
+
 	if(mid){
 		if(mqtt3_db_message_delete(context->id, mid, md_out)) return 1;
 	}
@@ -115,6 +128,12 @@ int mqtt3_handle_pubcomp(mqtt3_context *context)
 	if(mqtt3_read_uint16(context, &mid)) return 1;
 	mqtt3_log_printf(MQTT3_LOG_DEBUG, "Received PUBCOMP from %s (Mid: %d)", context->id, mid);
 
+#ifdef WITH_CLIENT
+	if(client_pubcomp_callback){
+		client_pubcomp_callback(mid);
+	}
+#endif
+
 	if(mid){
 		if(mqtt3_db_message_delete(context->id, mid, md_out)) return 1;
 	}
